PyBaccarat: tests.test_card Namespace Reference

PyBaccarat visit the ministry of silly walks

Classes | Variables
tests.test_card Namespace Reference

Unit test for the Card class. More...

## Classes
class | TestCard

## Variables
| HERE = os.path.dirname(os.path.abspath(__file__))

## Detailed Description

Unit test for the Card class.

To execute the unit test from base dir location, enter:

cd pybaccarat_base
python tests\unittest_card.py [-v]

Author
  fulkg.nosp@m.l@gm.nosp@m.ail.c.nosp@m.om